@@ -11,17 +11,18 @@
 #![deny(unsafe_code)]
 #![deny(clippy::all)]
 #![deny(clippy::pedantic)]
-// Makes for confusing SNAFU context selectors
-#![allow(clippy::pub_enum_variant_names)]
 // Triggered by many derive macros (kube-derive, derivative)
 #![allow(clippy::default_trait_access)]
 #![allow(clippy::type_repetition_in_bounds)]
+// Triggered by Tokio macros
+#![allow(clippy::semicolon_if_nothing_returned)]
 
 pub mod controller;
 pub mod finalizer;
 pub mod reflector;
 pub mod scheduler;
 pub mod utils;
+pub mod wait;
 pub mod watcher;
 
 pub use controller::{applier, Controller};
